==> rosegarden_1.6.1.orig.tar.gz: rosegarden-1.6.1/src/commands/segment/SetTriggerSegmentDefaultRetuneCommand.h <==

/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.

    This program is Copyright 2000-2007
        Guillaume Laurent   <glaurent@telegraph-road.org>,
        Chris Cannam        <cannam@all-day-breakfast.com>,
        Richard Bown        <richard.bown@ferventsoftware.com>

    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
    Bown to claim authorship of this work have been asserted.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef _RG_SETTRIGGERSEGMENTDEFAULTRETUNECOMMAND_H_
#define _RG_SETTRIGGERSEGMENTDEFAULTRETUNECOMMAND_H_

#include "base/TriggerSegment.h"
#include <kcommand.h>




namespace Rosegarden
{

class Composition;


class SetTriggerSegmentDefaultRetuneCommand : public KNamedCommand
{
public:
    SetTriggerSegmentDefaultRetuneCommand(Composition *composition,
                                          TriggerSegmentId id,
                                          bool newDefaultRetune);
    virtual ~SetTriggerSegmentDefaultRetuneCommand();

    virtual void execute();
    virtual void unexecute();

protected:
    Composition *m_composition;
    TriggerSegmentId m_id;
    bool m_newDefaultRetune;
    bool m_oldDefaultRetune;
    bool m_haveOldDefaultRetune;
};



}

#endif

==> rosegarden_10.04.2.orig.tar.gz: rosegarden-10.04.2/src/commands/segment/SetTriggerSegmentDefaultRetuneCommand.h <==

/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.
    Copyright 2000-2010 the Rosegarden development team.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef _RG_SETTRIGGERSEGMENTDEFAULTRETUNECOMMAND_H_
#define _RG_SETTRIGGERSEGMENTDEFAULTRETUNECOMMAND_H_

#include "base/TriggerSegment.h"
#include "document/Command.h"

#include <QCoreApplication>


namespace Rosegarden
{

class Composition;


class SetTriggerSegmentDefaultRetuneCommand : public NamedCommand
{
    Q_DECLARE_TR_FUNCTIONS(Rosegarden::SetTriggerSegmentDefaultRetuneCommand)

public:
    SetTriggerSegmentDefaultRetuneCommand(Composition *composition,
                                          TriggerSegmentId id,
                                          bool newDefaultRetune);
    virtual ~SetTriggerSegmentDefaultRetuneCommand();

    virtual void execute();
    virtual void unexecute();

protected:
    Composition *m_composition;
    TriggerSegmentId m_id;
    bool m_newDefaultRetune;
    bool m_oldDefaultRetune;
    bool m_haveOldDefaultRetune;
};



}

#endif
